@@ -306,20 +306,18 @@ class AutopartitionHelper:
     Helper for autopartiton device and mount point creating
     """
     def deviceOpts(self,listvalue): 
-        for i in ("root","data"):
-            if i in listvalue:
-                beforeVal = i
+        l = [x for x in listvalue if x not in ("home","lvm","raid","grub")]
+        for i in ("uefi", "swap", "boot"):
+            if i in l:
+                l.remove(i)
+                yield i
                 break
-        else:
-            beforeVal = ""
-        for line in listvalue:
-            if line in ("home","lvm","raid","grub"):
-                continue
-            if line == beforeVal:
-                yield "root2"
-            yield line
-        if not beforeVal:
-            yield "root2"
+        yield "root2"
+        if "root" in l:
+            l.remove("root")
+            yield "root"
+        for i in l:
+            yield i
 
     def bindOpts(self,listvalue):
         return filter(lambda x:x in ("home",),
@@ -344,11 +342,12 @@ class AutopartitionHelper:
 
     def getAutopartitionScheme(self):
         optOrder = {'uefi':0,
-                    'boot':1,
-                    'swap':2,
-                    'root':3,
-                    'data':4,
-                    'home':5}
+                    'root':1,
+                    'home':2,
+                    'swap':3,
+                    'boot':4,
+                    'data':5,
+        }
         return sorted(self.Get('cl_autopartition_scheme'),key=optOrder.get)
 
     def uncompatible(self):
@@ -492,7 +491,7 @@ class VariableClAutopartitionSet(Variable):
     type = "bool"
     value = "off"
     element = "radio"
-    opt = ["--autopartition", "-P"]
+    opt = ["--autopartition", "-p"]
 
     def init(self):
         self.label = _("Partitions")
